Llevar a cabo una evaluación de riesgos con OiRA | OiRA

Temas

# Llevar a cabo una evaluación de riesgos con OiRA

## Iniciar una nueva sesión

Para iniciar una nueva evaluación de riesgos, haga clic en el enlace «Iniciar una nueva sesión».

## Apertura de una evaluación de riesgos

Una vez que haya iniciado una evaluación de riesgos, podrá recuperarla en cualquier momento a través del tablero de control «Mis evaluaciones de riesgos». Desde este mismo lugar puede iniciar una nueva evaluación de riesgos.

Tablero de control

## Navegar una evaluación de riesgos

Cada evaluación de riesgos le guía a través de varios pasos. Se pueden ver en el menú principal, en el lado izquierdo:

- Preparación
- Participación
- Identificación + Evaluación
- Plan de acción
- Informe
- Grado de cumplimentación

En función de las decisiones adoptadas por los socios/desarrolladores de la herramientas OiRA, la arquitectura de la herramienta específica puede variar. En algunas herramientas, la fase de identificación y evaluación de riesgos también incluye directamente el plan de acción. En este caso, el menú de la izquierda contiene los siguientes puntos:

- Preparación
- Participación
- Evaluación
- Informe
- Grado de cumplimentación

## Preparación

La preparación es donde inicia usted automáticamente cada sesión/herramienta. Aquí es donde asigna un nombre a la evaluación de riesgos que le ayudará posteriormente a diferenciar distintas evaluaciones de riesgos que haya realizado con la herramienta.

El enlace «Aprenda más sobre esta herramienta…» muestra información adicional, específicamente sobre la herramienta seleccionada y sobre las partes que intervienen en el desarrollo.

Después de hacer clic en el botón «Iniciar», es posible que se le formulen algunas preguntas adicionales, dependiendo de la herramienta que esté utilizando. Esta página de preparación con «preguntas de perfil» solo aparece en las herramientas que ofrecen esta opción.

Aquí puede:

- Seleccionar u omitir situaciones pertinentes o no en función de que resulten aplicables a la actividad de su empresa. Elija «Sí», en su caso.
- Indique las múltiples unidades de negocio, sucursales o tiendas, etc. Los riesgos relacionados se repetirán para cada nombre que haya introducido.

La pantalla «Perfil» en el paso de Preparación

El paso de preparación es muy importante, ya que define con precisión el tipo de actividad y los riesgos relacionados a los que hace frente su empresa. Después de hacer clic en «Guardar y continuar», se le dirigirá automáticamente a la siguiente sección «Participación».

Nota: Muchas herramientas no incluyen preguntas sobre el perfil, ya que no utilizan esta función para dirigir la herramienta. En ese caso, esta pantalla se salta automáticamente.

## Participación

Este paso le recuerda la importancia de la participación de los trabajadores y ofrece diferentes posibilidades para garantizarla. Aquí puede descargar o imprimir el contenido de la evaluación de riesgos, para que pueda compartirlo con sus trabajadores/empleados. Esto garantiza que los trabajadores puedan contribuir a la tarea de evaluar la situación en su lugar de trabajo.

## Identificación + evaluación

En esta fase, identificará usted los peligros y problemas de su empresa.

Nota: Dependiendo de cómo haya configurado el socio de OiRA una herramienta OiRA, el paso «Plan de acción» (véase más adelante) ya puede integrarse en esta pantalla. En este caso, todo el paso se denomina «Evaluación», y los elementos descritos a continuación en el apartado «Plan de acción» aparecerán bajo la identificación y evaluación de cada riesgo.

Identificación + Evaluación.

A la izquierda de la página, debajo de «Identificación + Evaluación»/ «Evaluación», puede ver todos los temas/módulos incluidos en la herramienta. El tema que está viendo en este momento aparece resaltado.

Para cada riesgo individual, debe decidir si la declaración descrita de un estado positivo es válida para su empresa:

- Sí: si responde afirmativamente en el encabezado con un «sí», no es necesario que haga nada más, ya que ha evaluado que el riesgo no existe.
- No: si responde con un «no», debe tomar más medidas. Se le pedirá que decida medidas específicas.
- No procede: Algunas declaraciones de riesgo le ofrecen la posibilidad de seleccionar «no procede» si el riesgo no es pertinente para su empresa/centro de trabajo.

Normalmente, bajo cada declaración a la que debe responder se incluye información adicional sobre qué es un riesgo específico:

- Información: una breve descripción, opcionalmente con imágenes ilustrativas, ofrece más detalles sobre el riesgo.
- Recursos: información adicional sobre el riesgo, como referencias legales y políticas. En ocasiones también puede encontrar aquí documentos adjuntos para ampliar la información.
- Comentarios: aquí puede incluir sus propios comentarios, que aparecerán en su informe al final de la evaluación.

Después de responder a una declaración de riesgos y continuar, el menú de la izquierda se actualizará con un símbolo en color, para indicar si ha

- contestado afirmativamente (marca en verde)
- contestado negativamente (cruz roja)
- pospuesto (signo de interrogación en amarillo)
- en el caso de las preguntas sin respuesta, se mantiene el símbolo gris.

### Evaluación

En este paso evalúa usted la prioridad de un riesgo que haya identificado.

Evaluar un riesgo

Nota: En algunas herramientas OiRA, la evaluación no se muestra en absoluto. Esto depende de cómo el socio en cuestión haya configurado una herramienta OiRA particular.

Si ha identificado un riesgo como existente (se muestra la cruz roja), aparecerá la sección de evaluación. En función del método de evaluación establecido para cada riesgo, se le pedirá que:

- estime directamente la prioridad: alta, media o baja

Establecer la prioridad de un riesgo

O

- responder a tres preguntas sobre la frecuencia, la gravedad y la probabilidad del riesgo, de manera que la prioridad pueda calcularse basándose en sus respuestas.

Establecer variables para un riesgo

### Riesgos prioritarios establecidos por el sector:

Algunos riesgos son considerados de alta importancia por el socio o desarrollador respectivo de la herramienta que creó la herramienta OiRA específica. No es necesario que calcule usted dichos «riesgos prioritarios», ya que su prioridad se establecerá automáticamente como «alta».

Riesgos prioritarios

### Riesgos personalizados

Una vez que haya terminado de responder a todos los temas de riesgo en «Identificación + Evaluación»/ «Evaluación», llegará al tema opcional «Riesgos añadidos». Aquí, el botón «Añadir otro riesgo» le permite crear sus propias entradas.

Si detecta que determinados riesgos que existen en su lugar de trabajo o en su empresa no aparecen en la herramienta, debe añadir aquí los riesgos personalizados. Puede usted definir o formular íntegramente estos riesgos.

Riesgos personalizados

Un «riesgo personalizado» funciona de manera muy similar a los riesgos que ofrece la herramienta OiRA, pero evidentemente es necesario que redacte usted su propio texto: una breve declaración en la que describa una situación problemática (declaración positiva) y opcionalmente una descripción más larga. También puede subir una imagen para ilustrar una situación determinada.

Al igual que ocurre con los riesgos habituales, debe declarar si el riesgo existe o no. Esto le ofrece la posibilidad de descartar los riesgos personalizados una vez que los haya abordado con éxito, pero conservarlos en su evaluación de riesgos a efectos de documentación.

Puede añadir tantos riesgos personalizados como sea necesario.

Añadir un riesgo personalizado

## Plan de acción

En este paso decide usted las medidas que quiere aplicar para eliminar o mitigar los riesgos que ha identificado anteriormente.

Nota: Como se ha mencionado anteriormente, el plan de acción se presenta como un paso separado resaltado en el menú de la izquierda o como un paso en cada riesgo identificado. En este último caso, el paso en el menú de la izquierda se llama «Evaluación» e incluye tanto las declaraciones de riesgo que deben responderse como las soluciones que es preciso elegir.

La versión que se le facilita depende de las decisiones que tome el socio/desarrollador nacional de la herramienta OiRA.

Iniciar el plan de acción.

Haga clic en el botón «Crear plan de acción» para comenzar su plan.

En el paso del plan de acción, el menú principal de la izquierda solo muestra ahora los riesgos marcados para acciones posteriores, dado que se marcaron los otros riesgos como no existentes.

Para cada riesgo al que haya respondido con un «No» durante el proceso de evaluación y para los riesgos prioritarios (independientemente de que se hayan respondido de manera positiva o negativa) se le pedirá que defina medidas.

El Plan de acción

Puede seleccionar entre una lista de medidas propuestas por el sistema o definir sus propias medidas.

### Añadir su propia medida

Añadir su propia medida

Utilice el botón «Añadir otra medida» para comenzar a definir una medida preventiva. Complete la siguiente información:

- Describa el enfoque general que se adoptará para eliminar o reducir el riesgo.
- Indicar opcionalmente el nivel de experiencia o los requisitos necesarios (por ejemplo, aquí puede añadir si se necesita formación específica o experiencia externa para abordar este riesgo)
- Introduzca información sobre quién es responsable de la aplicación.
- Defina un presupuesto, si procede.
- De manera opcional, establezca fechas para comenzar a aplicar la medida y cuándo tiene previsto que finalice.

Puede añadir tantas medidas como sea necesario.

### Añadir medida habitual

Dependiendo de cómo haya configurado la herramienta OiRA el socio/desarrollador correspondiente, se dispone de medidas pre-establecidas para los riesgos individuales. Para elegir una o más medidas pre-establecidas, haga clic en el botón «Seleccionar medidas pre-establecidas».

Se abre un menú emergente que muestra todas las medidas propuestas. Haga clic en el botón «Añadir» que figura detrás de las medidas que desea utilizar.

Las medidas pre-establecidas se incluyen a continuación en su plan de acción. La descripción de lo que se debe hacer es fija, pero puede y debe usted cumplimentar los demás campos (responsabilidad, presupuesto, fechas).

Añadir medida habitual.

Las medidas habituales y las medidas definidas por usted pueden volver a eliminarse en cualquier momento.

## Informe

Después de finalizar el plan de acción, puede descargar un informe.

Si desea dejar un comentario para que se incluya en el informe, escriba su texto aquí y guárdelo.

Comente el informe

Consulte aquí para acceder a información adicional sobre los diferentes informes y cómo utilizarlos.

## Grado de cumplimentación

El pequeño gráfico circular que figura en el menú de la izquierda le muestra el progreso general que ya ha hecho en la herramienta.

La sección de grado de cumplimentación le ofrece una visión general de cuántos riesgos ha identificado, cuántos de ellos ha abordado ya mediante la decisión de medidas y a cuántos riesgos/declaraciones no ha respondido todavía.

Página de grado de cumplimentación.

Si entra en la página de grado de cumplimentación, podrá ver cuánto ha avanzado en cada módulo. Esto puede ayudarle a saber dónde sigue necesitando evaluar los riesgos o proporcionar medidas para los riesgos que ha identificado.

Scroll to top Load toolbar…
Back

## 3-carrying-out-a-risk-assessment.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More